Module: RustPdf::VerticalAlign
- Defined in:
- lib/rustpdf.rb
Overview
Vertical alignment of the line inside a masked_text box. MIDDLE is the historical cap-height centering; TOP hangs the line from the top edge (top line-alignment in rectangle-based text APIs semantics); BOTTOM rests the descender line on the bottom edge.
Constant Summary collapse
- TOP =
0- MIDDLE =
1- BOTTOM =
2